==> silentbob-1.7.6.tar.gz: silentbob-1.7.6/src/usage.cxx <==

/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * (c) Oleg Puchinin 2006,2007
 * graycardinalster@gmail.com
 * 
 */ 

#include <stdio.h>

void usage ()
{
	printf ("usage:\tsilent_bob [<kernel_function>|<files>] [<options>]\n");
	printf ("\ttags <tag> <tag2> ... <tagN> [<options>]\n");
	printf ("\t options:\n"
			"\t\t -C <dir>\t\t-\tchdir to <dir>\n"
			"\t\t--cgrep\t\t\t-\tsearch in code\n"
			"\t\t--call-tags\t\t-\tcreate \"call_tags\" file\n"
			"\t\t--cfiles\t\t-\tcreate \"cfiles\" file\n"
			"\t\t--ctags-append\t\t-\tdon't rewrite \"tags\" file\n"
			"\t\t--depth <arg>\t\t-\tset reentrant level\n"
			"\t\t--file <files>\t\t-\tshow file functions\n"
			"\t\t -fn\t\t\t-\techo filenames\n"
			"\t\t--structs\t\t-\tshow all structs in stream\n"
			"\t\t -i\t\t\t-\tinteractive mode \"tags\"\n"
			"\t\t--indent\t\t-\tindention\n"
			"\t\t -j\t\t\t-\tnumber of jobs\n"
			"\t\t--kinds\t\t\t-\t(a - all, c - classes, s - structs, f - functions)\n"
			"\t\t--L <file>\t\t-\tread files list from file\n"
			"\t\t--make-ctags\t\t-\tcreate \"tags\" file\n"
//			"\t\t--plugins-info\t\t-\tshow available plugins\n"
//			"\t\t--plugin <id>\t\t-\tshow plugin usage info\n"
			"\t\t--plugins-viewer\t-\tplugins viewer\n"
			"\t\t--the-tt\t\t-\tC preprocessor\n"
			"\t\t -ts\t\t\t-\tforce ctags style\n"
			"\t\t -u\t\t\t-\treverse call-tree\n"
			"\t\t--verbose\t\t-\tprint more other info\n"
			);
	
	printf ("\nCONTACTS\nOleg Puchinin <graycardinalster@gmail.com>\n");
}

==> silentbob-2.2.tar.gz: silentbob-2.2/src/usage.cxx <==
/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * (c) Oleg Puchinin 2009
 * graycardinalster@gmail.com
 * 
 */ 

#include <stdio.h>

void usage ()
{
	printf ("usage:\t bob [<function>|<files>] [<options>]\n");
	printf ("\t options:\n"
			"\t\t -C <dir>\t\t-\tchdir to <dir>\n"
			"\t\t--cgrep\t\t\t-\tsearch in code\n"
			"\t\t--grep\t\t\t-\tsearch text\n"
			"\t\t--call-tags\t\t-\tcreate \"call_tags\" file\n"
			"\t\t -f\t\t\t-\tcreate \"files\" file\n"
			"\t\t--ctags-append\t\t-\tdon't rewrite \"tags\" file\n"
			"\t\t--depth <arg>\t\t-\tset reentrant level\n"
			"\t\t--file <files>\t\t-\tshow file functions\n"
			"\t\t -fn\t\t\t-\techo filenames\n"
			"\t\t--structs\t\t-\tshow all structs in stream\n"
			"\t\t -i\t\t\t-\tinteractive mode \"tags\"\n"
			"\t\t--indent\t\t-\tindention\n"
			//"\t\t -j\t\t\t-\tnumber of jobs\n"
			"\t\t--kinds\t\t\t-\t(c - classes, s - structs, f - functions,\n"
		   "\t\t\t\t\t\tm - modules, n - namespaces, p - packages)\n"
			"\t\t--L <file>\t\t-\tread files list from file\n"
			"\t\t -c\t\t\t-\tcreate \"tags\" file\n"
//			"\t\t--plugins-info\t\t-\tshow available plugins\n"
//			"\t\t--plugin <id>\t\t-\tshow plugin usage info\n"
//			"\t\t--plugins-viewer\t-\tplugins viewer\n"
			"\t\t--the-tt\t\t-\tC preprocessor\n"
			"\t\t -ts\t\t\t-\tforce ctags style\n"
			"\t\t -u\t\t\t-\treverse call-tree\n"
	//		"\t\t--verbose\t\t-\tprint more other info\n"
			);
	
	printf ("\nCONTACTS\nOleg Puchinin <graycardinalster@gmail.com>\n");
}
